@@ -9,9 +9,10 @@ import numpy as np
 import warnings
 import time
 from .lp import Solution
+from numbers import Real
 
 
-def solve(formula, display=True, export=False, params={}):
+def solve(formula, display=True, params={}):
 
     try:
         if formula.qmat:
@@ -35,7 +36,8 @@ def solve(formula, display=True, export=False, params={}):
     row, col = linear.shape
 
     xs = [solver.NumVar(lb[i], ub[i], 'x' + str(i)) if vtype[i] == 'C' else
-          solver.IntVar(0, 1, 'x' + str(i)) if vtype[i] == 'B' else
+          solver.IntVar(max(0, lb[i]), min(1, ub[i]),
+                        'x' + str(i)) if vtype[i] == 'B' else
           solver.IntVar(lb[i], ub[i], 'x' + str(i)) for i in range(col)]
 
     solver.Minimize(sum([obj[i] * xs[i] for i in range(col)]))
@@ -44,12 +46,12 @@ def solve(formula, display=True, export=False, params={}):
         indices = linear[j].indices
         coeff = linear[j].data
         nz = len(indices)
-        if sense[j] == 1:
-            solver.Add(sum([coeff[i] * xs[indices[i]]
-                            for i in range(nz)]) == const[j])
-        else:
-            solver.Add(sum([coeff[i] * xs[indices[i]]
-                            for i in range(nz)]) <= const[j])
+        left = sum([coeff[i] * xs[indices[i]] for i in range(nz)])
+        if not isinstance(left, Real):
+            if sense[j] == 1:
+                solver.Add(left == const[j])
+            else:
+                solver.Add(left <= const[j])
 
     if display:
         print('Being solved by OR-Tools...', flush=True)
